package Depot::ReadConfig;

# ReadConfig.pm -- author: Oliver Bossert
# Copyright (C) 2004 Oliver Bossert
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

use strict;

use Depot::Conf;

use XML::Simple;
use Data::Dumper;


############################################################
sub new { # Generate a new Object
############################################################
  my $type = shift;
  my $class = ref($type) || $type;
  my $self = {};
  bless $self, $class;

  Depot::Conf::default("Config::Basedir", ".");
  $self->{'basedir'} = Depot::Conf::get("Config::Basedir");

  return $self;
}

############################################################
sub readindex {
############################################################
  my $self = shift;
  my $xs = new XML::Simple(KeyAttr => [ 'depot' ],
			   ForceArray => [ 'depot' ]);
  $self->{'index'} = $xs->XMLin($self->{'basedir'} . "/depot-index.xml");
}

############################################################
sub writeindex {
############################################################
  my $self = shift;
  my $xs = new XML::Simple( XMLDecl => 1 );
  my $string = $xs->XMLout($self->{'index'});
  open CONF, ">" . $self->{'basedir'} . "/depot-index.xml" or die
    "Could not write in file: " . $self->{'basedir'} . "/depot-index.xml";
  print CONF $string;
  close CONF;
}

############################################################
sub readdepots {
############################################################
  my $self = shift;
  my $xs = new XML::Simple( KeyAttr => [ 'trade', 'position', 'order', 'param', 'comment' ],
			    ForceArray => [ 'trade', 'position', 'order', 'param', 'comment' ]);
  foreach my $depot (@{$self->{'index'}->{'depot'}}) {
    $self->{'depots'}{$depot->{'file'}} = $xs->XMLin( $self->{'basedir'} . "/" . $depot->{'file'} );
#    print Dumper( $self->{'depots'}->{$depot->{'file'}} );
  }
}

############################################################
sub writedepots {
############################################################
  my $self = shift;
  my $xs = new XML::Simple( XMLDecl => 1 );

  foreach my $depot ( keys %{$self->{'depots'}} ) {

    next if ( $depot eq "" );

    # Check if this is a new depot
    my $newdepot = 1;
    foreach my $depot_idx ( @{$self->{'index'}->{'depot'}} ) {
      if ( $depot_idx->{'file'} eq $depot) {
	$newdepot = 0;
      }
    }
    if ( $newdepot == 1 ) {
      my $d = {};
      $d->{'file'} = $depot;
      $d->{'name'} = $self->{'depots'}->{$depot}->{'depot'}->{'name'};
      push @{$self->{'index'}->{'depot'}}, $d;
    }

    # Write it to a file
    my $string = $xs->XMLout( $self->{'depots'}->{$depot} );
    #print $string;
    open DEP, ">" . $self->{'basedir'} . "/" . $depot or die
      "Could not write in file: " . $self->{'basedir'} . "/" . $depot . ": $!";
    print DEP $string;
    close DEP;

  }
}




############################################################
sub get {
############################################################
  my $self = shift;
  $self->readindex();
  $self->readdepots();
}

############################################################
sub set {
############################################################
  my $self = shift;
  $self->writedepots();
  $self->writeindex();
}




1;
