package Depot::Tools;

# Tools.pm -- author: Oliver Bossert
# Copyright (C) 2004 Oliver Bossert
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

use strict;
use Finance::Quote;

use vars qw(@ISA @EXPORT %CACHE);
require Exporter;
@ISA = qw(Exporter);
@EXPORT = qw(translatecode timestamp getval getvolume);


############################################################
sub translatecode { # Translates WKN to Yahoo-ID
############################################################
  my $code = shift;
  if ( defined($code) && $code =~ /\d{6}/i ) {
    $code .= ".DE";
  }
  return $code;
}

############################################################
sub timestamp { # Creates a timestamp
############################################################
  my @t = localtime(time);
  $t[5] += 1900;
  $t[4] += 1;
  my $date = sprintf("%04d-%02d-%02d_%02d:%02d:%02d", $t[5], $t[4], $t[3], $t[2], $t[1], $t[0]);
  return $date;
}

############################################################
sub getval { # Returns the value of a Stock
############################################################
# Enable this for testing offline
#  return 50;
  my $wkn = shift;
  my $type = shift || "price";

  return $CACHE{$wkn}{$type} if (defined($CACHE{$wkn}{$type}));

  my $q = Finance::Quote->new;
  $q->timeout(60);
  $q->set_currency("EUR");
  $wkn = translatecode($wkn);
  my %quotes  = $q->fetch("europe",$wkn);
  my $value;
  $value = $quotes{$wkn, $type};

  $CACHE{$wkn}{$type} = $value;
  $CACHE{$wkn}{'volume'} = $quotes{$wkn, "volume"} if ( defined($quotes{$wkn, "volume"}) );
  return $value;
}

############################################################
sub getvolume { # Returns the value of a Stock
############################################################
# Enable this for testing offline
#  return 1;
  my $wkn = shift;

  return $CACHE{$wkn}{'volume'} if (defined($CACHE{$wkn}{'volume'}));

  my $q = Finance::Quote->new;
  $q->timeout(60);
  $q->set_currency("EUR");
  $wkn = translatecode($wkn);
  my %quotes  = $q->fetch("europe",$wkn);

  $CACHE{$wkn}{'volume'} = $quotes{$wkn, "volume"} if ( defined($quotes{$wkn, "volume"}) );
  return $CACHE{$wkn}{'volume'};
}


1;
